==> zeusmp1.5.13.tar.gz: zeusmp/src/mod_names.h <==
/*
  mod_names.h gives various routine names on a variety of systems.  This
  primarily takes care of whether trailing underscores are added by the
  FORTRAN compiler.
  
  RAF 2/13/96
*/

#ifdef LINUX
#define MPI_WAITALL MPI_WAITALL_
#define MPI_IRECV MPI_IRECV_
#define MPI_ISEND MPI_ISEND_
#define MPI_WTIME MPI_WTIME_
#define MPI_FINALIZE MPI_FINALIZE_
#define MPI_BCAST MPI_BCAST_
#define MPI_BARRIER MPI_BARRIER_
#define MPI_CART_CREATE MPI_CART_CREATE_
#define MPI_COMM_RANK MPI_COMM_RANK_
#define MPI_CART_SHIFT MPI_CART_SHIFT_
#define MPI_CART_COORDS MPI_CART_COORDS_
#define MPI_TYPE_VECTOR MPI_TYPE_VECTOR_
#define MPI_TYPE_COMMIT MPI_TYPE_COMMIT_
#define MPI_REDUCE MPI_REDUCE_
#define MPI_Reduce MPI_Reduce_
#define MPI_GATHER MPI_GATHER_
#define MPI_Gather MPI_Gather_
#define MPI_COMM_SIZE MPI_COMM_SIZE_
#define MPI_ALLREDUCE MPI_ALLREDUCE_
#define MPI_INIT MPI_INIT_
#define ETIME etime
#endif

#if defined HP || defined IBM || defined EXEMPLAR
 
#ifdef HP
#define ETIME   etime_
#define ITIME   itime_
#define CHECKIN checkin_
#define BCDFLT  bcdflt_
#ifdef SINGLE_PRECISON
#define ISMAX   ismax
#define SASUM   sasum
#else
#define ISMAX   idmax
#define SASUM   sasum
#endif
#endif
 
#ifdef IBM
#define ETIME   etime_
#define ITIME   itime_
#define CHECKIN checkin_
#define BCDFLT  bcdflt_
#ifdef SINGLE_PRECISON
#define ISMAX   ismax
#define SASUM   sasum
#else
#define ISMAX   idmax
#define SASUM   sasum
#endif
#endif
 
#ifdef EXEMPLAR
#define ETIME   etime
#define ITIME   itime
#define CHECKIN checkin_
#define BCDFLT  bcdflt_
#define ISMAX   ismax
#define SASUM   sasum
#endif
 
#else /* defined HP || defined IBM || defined EXEMPLAR */
/* 
  On many systems, underscores are appended to the names of both user
  and system library C routines automatically.
*/
#define ETIME etime
#define ITIME itime
#define CHECKIN checkin
#define BCDFLT  bcdflt
#if defined SINGLE_PRECISON || defined UNICOS || defined CONVEXOS
#define ISMAX   ismax
#define SASUM   sasum
#else
#define ISMAX   idmax
#define SASUM   sasum
#endif
#endif

==> zeusmp1.5.18.tar.gz: zeusmp/src/mod_names.h <==
/*
  mod_names.h gives various routine names on a variety of systems.  This
  primarily takes care of whether trailing underscores are added by the
  FORTRAN compiler.
  
  RAF 2/13/96
*/

#ifdef LINUX
#define MPI_WAITALL MPI_WAITALL_
#define MPI_IRECV MPI_IRECV_
#define MPI_ISEND MPI_ISEND_
#define MPI_WTIME MPI_WTIME_
#define MPI_FINALIZE MPI_FINALIZE_
#define MPI_BCAST MPI_BCAST_
#define MPI_BARRIER MPI_BARRIER_
#define MPI_CART_CREATE MPI_CART_CREATE_
#define MPI_COMM_RANK MPI_COMM_RANK_
#define MPI_CART_SHIFT MPI_CART_SHIFT_
#define MPI_CART_COORDS MPI_CART_COORDS_
#define MPI_TYPE_VECTOR MPI_TYPE_VECTOR_
#define MPI_TYPE_COMMIT MPI_TYPE_COMMIT_
#define MPI_REDUCE MPI_REDUCE_
#define MPI_Reduce MPI_Reduce_
#define MPI_GATHER MPI_GATHER_
#define MPI_Gather MPI_Gather_
#define MPI_COMM_SIZE MPI_COMM_SIZE_
#define MPI_ALLREDUCE MPI_ALLREDUCE_
#define MPI_INIT MPI_INIT_
#define ETIME etime
#endif

#if defined HP || defined IBM || defined EXEMPLAR
 
#ifdef HP
#define ETIME   etime_
#define ITIME   itime_
#define CHECKIN checkin_
#define BCDFLT  bcdflt_
#ifdef SINGLE_PRECISION
#define ISMAX   ismax
#define SASUM   sasum
#else
#define ISMAX   idmax
#define SASUM   sasum
#endif
#endif
 
#ifdef IBM
#define ETIME   etime_
#define ITIME   itime_
#define CHECKIN checkin_
#define BCDFLT  bcdflt_
#ifdef SINGLE_PRECISION
#define ISMAX   ismax
#define SASUM   sasum
#else
#define ISMAX   idmax
#define SASUM   sasum
#endif
#endif
 
#ifdef EXEMPLAR
#define ETIME   etime
#define ITIME   itime
#define CHECKIN checkin_
#define BCDFLT  bcdflt_
#define ISMAX   ismax
#define SASUM   sasum
#endif
 
#else /* defined HP || defined IBM || defined EXEMPLAR */
/* 
  On many systems, underscores are appended to the names of both user
  and system library C routines automatically.
*/
#define ETIME etime
#define ITIME itime
#define CHECKIN checkin
#define BCDFLT  bcdflt
#if defined SINGLE_PRECISION || defined UNICOS || defined CONVEXOS
#define ISMAX   ismax
#define SASUM   sasum
#else
#define ISMAX   idmax
#define SASUM   sasum
#endif
#endif
